
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.93'
version = '1.2.93'
full_version = '1.2.93'
git_revision = '8341fbf5bd21d1bd053ed4dcdee6d430fd085d4d'
release = True

if not release:
    version = full_version
    short_version += ".dev"
